PR.GUI.Color = {
    White = "255 255 255",
    Red = "255 0 0",
    Green = "0 255 0",
    Cyan = "0 255 255",
    Magenta = "255 0 255",
    Gold = "255 215 0",
    LightGray = "211 211 211",
    Gray = "169 169 169",
    Tomato = "255 99 71",
    Orange = "255 165 0",
    Button = tabunseltextcolor,
    RowHighlight = textlistboxselcolor,
}

for name, rgb in pairs(PR.GUI.Color) do
    PR.Color[name] = rgbtohex(rgb)
end
PR.Color.TERMINATOR = "\127o" -- custom color terminator
PR.Color.FactionColors = {
    Gray = rgbtohex(FactionColor_RGB[0]),
    Itani = rgbtohex(FactionColor_RGB[1]),
    Serco = rgbtohex(FactionColor_RGB[2]),
    UIT = rgbtohex(FactionColor_RGB[3]),
    Developers = PR.Color.Magenta
}

-- This table holds all the ore related static data.
-- The order here determines the order the GUI cycles through them, so
-- it should be sorted by descending XP value.
-- See https://www.vo-wiki.com/wiki/Mining#List_of_Ores
PR.Ore = {
    { name = "Sammic",     shortname = "Sa", xp = 25, color = PR.Color.Gray },
    { name = "Heliocene",  shortname = "He", xp = 20, color = PR.Color.Red },
    { name = "Pentric",    shortname = "Pe", xp = 18, color = rgbtohex("212 212 42") },
    { name = "Denic",      shortname = "De", xp = 15, color = rgbtohex("18 164 210") },
    { name = "Apicene",    shortname = "Ap", xp = 14, color = rgbtohex("50 100 150") },
    { name = "Pyronic",    shortname = "Py", xp = 12, color = rgbtohex("236 142 114") },
    { name = "Lanthanic",  shortname = "La", xp = 10, color = rgbtohex("180 40 255") },
    { name = "Xithricite", shortname = "Xi", xp =  8, color = rgbtohex("0 255 64") },
    { name = "Ishik",      shortname = "Is", xp =  7, color = PR.Color.Cyan },
    { name = "VanAzek",    shortname = "Va", xp =  7, color = rgbtohex("171 107 84") },
    { name = "Ferric",     shortname = "Fe", xp =  6, color = PR.Color.LightGray },
    { name = "Carbonic",   shortname = "Ca", xp =  5, color = rgbtohex("102 153 102") },
    { name = "Silicate",   shortname = "Si", xp =  5, color = rgbtohex("204 204 153") },
    { name = "Aquean",     shortname = "Aq", xp =  4, color = rgbtohex("185 232 254") }
}
PR.Ore.n = #PR.Ore

-- array of system ownership, index is systemId
PR.SystemOwnership = {
    "Serco", -- 1: Sol II
    "Serco", -- 2: Betheshee
    "Serco", -- 3: Geira Rutilus
    "Itani", -- 4: Deneb
    "Itani", -- 5: Eo
    "Itani", -- 6: Cantus
    "Itani", -- 7: Metana
    "Itani", -- 8: Setalli Shinas
    "Itani", -- 9: Itan
    "Itani", -- 10: Pherona
    "Itani", -- 11: Artana Aquilus
    "Itani", -- 12: Divinia
    "Itani", -- 13: Jallik
    "Gray", -- 14: Edras
    "UIT", -- 15: Verasi
    "Gray", -- 16: Pelatus
    "Gray", -- 17: Bractus
    "UIT", -- 18: Nyrius
    "UIT", -- 19: Dau
    "Gray", -- 20: Sedina
    "UIT", -- 21: Azek
    "Gray", -- 22: Odia
    "Gray", -- 23: Latos
    "UIT", -- 24: Arta Caelestis
    "Gray", -- 25: Ukari
    "Gray", -- 26: Helios
    "Serco", -- 27: Initros
    "Serco", -- 28: Pyronis
    "Serco", -- 29: Rhamus
    "Serco", -- 30: Dantia
    "Developers", -- 31: Devlopia
    "Developers", -- 32: (Qualcomm Demo system)
    "Gray" -- 33: Unknown System
}
PR.SystemOwnership.n = #PR.SystemOwnership

-- array of { systemid, systemname } tables, sorted alphabetically,
-- only systems with names
PR.Systems = {}
-- will be filled in system.lua because we need one function there

PR.ConquerableStationSectors = {
    [4019] = true,
    [4317] = true,
    [5741] = true,
    [5753] = true
}
PR.WormholeLocations = {
    [223] = true,
    [226] = true,
    [276] = true,
    [351] = true,
    [575] = true,
    [748] = true,
    [815] = true,
    [946] = true,
    [1200] = true,
    [1203] = true,
    [1307] = true,
    [1377] = true,
    [1632] = true,
    [1783] = true,
    [1906] = true,
    [1999] = true,
    [2130] = true,
    [2144] = true,
    [2416] = true,
    [2514] = true,
    [2571] = true,
    [2658] = true,
    [2991] = true,
    [3009] = true,
    [3091] = true,
    [3301] = true,
    [3353] = true,
    [3490] = true,
    [3560] = true,
    [3603] = true,
    [3695] = true,
    [3863] = true,
    [4075] = true,
    [4117] = true,
    [4306] = true,
    [4498] = true,
    [4591] = true,
    [4703] = true,
    [4738] = true,
    [4837] = true,
    [4959] = true,
    [4978] = true,
    [5130] = true,
    [5369] = true,
    [5487] = true,
    [5570] = true,
    [5656] = true,
    [5714] = true,
    [5823] = true,
    [5844] = true,
    [5986] = true,
    [6079] = true,
    [6172] = true,
    [6210] = true,
    [6289] = true,
    [6351] = true,
    [6498] = true,
    [6591] = true,
    [6676] = true,
    [6847] = true,
    [6866] = true,
    [7055] = true,
    [7074] = true,
    [7147] = true,
    [7247] = true,
    [7250] = true,
    [7455] = true,
    [7490] = true,
    [7631] = true,
    [7682] = true,
    [8200] = true,
}
